@@ -1,6 +1,6 @@
 #' Save Identifications
 #' 
-#' @description Output identified results to an outfile.
+#' @description Output identified results to an outfile in temporty directory (found by tempdir() function).
 #' 
 #' @param  outfile character string to indicate outfile name.
 #' @param  ids object of class "BarcodingR", which contains identified taxon information. 
@@ -27,8 +27,17 @@ save.ids<-function(outfile="identified.txt",ids){
   
   #attributes(bsi)
   
+  Rhome<-tempdir() ### 2020/4/13 21:06:46
+  fileName<-outfile
+  fileName<-paste(Rhome,fileName,sep = "/")### 2020/4/13 21:06:46
+  #fileName<-paste(Rhome,fileName,sep = "\\")### 2020/4/13 21:06:46
+  fileName
+  #fileName<-paste("simulation",i,sep = "")
+  #fileName<-paste(fileName,".RData",sep = "")
+  #fileName
+  outfile<-fileName
   x<-ids$output_identified
-  
+  #x<-bsi$output_identified
   write.table(x, file = outfile, append = FALSE, quote = FALSE, sep = " ",
               eol = "\n", na = "NA", dec = ".", row.names = TRUE,
               col.names = TRUE, qmethod = c("escape", "double"),
